==> CGAL-5.6.1-doc_html.tar.xz: doc_html/BGL/group__PkgBGLAdaptors.js <==
var group__PkgBGLAdaptors =
[
    [ "Graph_with_descriptor_with_graph", "structCGAL_1_1Graph__with__descriptor__with__graph.html", null ],
    [ "Graph_with_descriptor_with_graph_property_map", "structCGAL_1_1Graph__with__descriptor__with__graph__property__map.html", null ],
    [ "Face_filtered_graph", "structCGAL_1_1Face__filtered__graph.html", [
      [ "edge_descriptor", "structCGAL_1_1Face__filtered__graph.html#a39d585ed86d262a090636cdd22ca1217", null ],
      [ "face_descriptor", "structCGAL_1_1Face__filtered__graph.html#a205b4716fba186d69d6527df34110939", null ],
      [ "halfedge_descriptor", "structCGAL_1_1Face__filtered__graph.html#a7bbe5ebea8b1792c366fdbea6efbd1b0", null ],
      [ "size_type", "structCGAL_1_1Face__filtered__graph.html#a9f6a738f2a87c25f5c5606071a5fb1d0", null ],
      [ "vertex_descriptor", "structCGAL_1_1Face__filtered__graph.html#a137cc0e8f6c8f4d7a916280085ea9947", null ],
      [ "Face_filtered_graph", "structCGAL_1_1Face__filtered__graph.html#a17421e034850157f1c586d25dc436ab8", null ],
      [ "Face_filtered_graph", "structCGAL_1_1Face__filtered__graph.html#a420095992349fd86cf0aacb173316e73", null ],
      [ "Face_filtered_graph", "structCGAL_1_1Face__filtered__graph.html#abf094836eb5948d27c204c776708cce9", null ],
      [ "Face_filtered_graph", "structCGAL_1_1Face__filtered__graph.html#ad4059cafe683c7b8e829957c6d22f231", null ],
      [ "graph", "structCGAL_1_1Face__filtered__graph.html#afe1f4d25eaf3117e1c3f94aed6070c17", null ],
      [ "graph", "structCGAL_1_1Face__filtered__graph.html#a7b01b76aca8ade3087d26e122c742b93", null ],
      [ "invert_selection", "structCGAL_1_1Face__filtered__graph.html#aa428541ebbdd35f9a6e9a3ffd60178df", null ],
      [ "is_selection_valid", "structCGAL_1_1Face__filtered__graph.html#ae11ebf8f8253a1ccfe3783fd45cd7380", null ],
      [ "number_of_faces", "structCGAL_1_1Face__filtered__graph.html#ac82d8efddf90cb302e16f3dfa6ace359", null ],
      [ "number_of_halfedges", "structCGAL_1_1Face__filtered__graph.html#a8adaca786ab8cb5bbdbe59c2e645d792", null ],
      [ "number_of_vertices", "structCGAL_1_1Face__filtered__graph.html#a170f192e48bcdebdffeda0513f2410b1", null ],
      [ "set_selected_faces", "structCGAL_1_1Face__filtered__graph.html#aca0fda876cf69d11207ad45752ef9fc5", null ],
      [ "set_selected_faces", "structCGAL_1_1Face__filtered__graph.html#a5322419b265a6cb33afedd05efa0b83f", null ],
      [ "set_selected_faces", "structCGAL_1_1Face__filtered__graph.html#a3a17351778505a646a75e150e5df47fb", null ]
    ] ],
    [ "Dual", "classCGAL_1_1Dual.html", [
      [ "Primal", "classCGAL_1_1Dual.html#a22a27f0319fa2626209231dfb37e4926", null ],
      [ "Dual", "classCGAL_1_1Dual.html#add5bcd5fa450de44a72f8fe633852528", null ],
      [ "primal", "classCGAL_1_1Dual.html#a2c7493b21787904e7d2dfd2cedaba9ec", null ],
      [ "dual", "classCGAL_1_1Dual.html#a85d851dbd90074098e101a10457f65a1", null ]
    ] ],
    [ "Seam_mesh", "classCGAL_1_1Seam__mesh.html", [
      [ "edge_descriptor", "classCGAL_1_1Seam__mesh_1_1edge__descriptor.html", null ],
      [ "halfedge_descriptor", "classCGAL_1_1Seam__mesh_1_1halfedge__descriptor.html", [
        [ "halfedge_descriptor", "classCGAL_1_1Seam__mesh_1_1halfedge__descriptor.html#ab5fbff698dd4a46833e6eb0ee121d7a6", null ],
        [ "halfedge_descriptor", "classCGAL_1_1Seam__mesh_1_1halfedge__descriptor.html#ad5b9578608046cc6d7b3ce239f14fbbf", null ]
      ] ],
      [ "vertex_descriptor", "classCGAL_1_1Seam__mesh_1_1vertex__descriptor.html", [
        [ "vertex_descriptor", "classCGAL_1_1Seam__mesh_1_1vertex__descriptor.html#aa4bbff0637b5892384a6cf0baac15807", null ],
        [ "vertex_descriptor", "classCGAL_1_1Seam__mesh_1_1vertex__descriptor.html#ac8180d4af2fb242cd5c505fb9e60e686", null ]
      ] ],
      [ "degree_size_type", "classCGAL_1_1Seam__mesh.html#a742e105a8131a63557915badc1e4786a", null ],
      [ "edges_size_type", "classCGAL_1_1Seam__mesh.html#a6d7b18cd7aa8e79cef2cd817c1b592b5", null ],
      [ "face_descriptor", "classCGAL_1_1Seam__mesh.html#a1685be3946d66eb747da43f7cea27886", null ],
      [ "faces_size_type", "classCGAL_1_1Seam__mesh.html#ac81e17c02d209fa8f7177f8f2593fe67", null ],
      [ "halfedges_size_type", "classCGAL_1_1Seam__mesh.html#a30b80a167cf5c1a07d374831382c6183", null ],
      [ "TM_edge_descriptor", "classCGAL_1_1Seam__mesh.html#a262560916f975ef799db0fe30cb0b33d", null ],
      [ "TM_halfedge_descriptor", "classCGAL_1_1Seam__mesh.html#a251a9f5e67ef5e5d988ce59f7b9a171b", null ],
      [ "TM_halfedge_iterator", "classCGAL_1_1Seam__mesh.html#a18c491d5a3e51cc6b6f2c8f37085b586", null ],
      [ "TM_vertex_descriptor", "classCGAL_1_1Seam__mesh.html#af23c272b8e2353bacee1ebd31ef340f3", null ],
      [ "Triangle_mesh", "classCGAL_1_1Seam__mesh.html#aa926867198e66ecf3d324e41a3312f18", null ],
      [ "vertices_size_type", "classCGAL_1_1Seam__mesh.html#a6a8680b26948b92e06448026b266a20e", null ],
      [ "Seam_mesh", "classCGAL_1_1Seam__mesh.html#a6042bff5f91a335aee1bd2573b57a29f", null ],
      [ "add_seam", "classCGAL_1_1Seam__mesh.html#a27d5997959e6a348e7206e359a378d85", null ],
      [ "add_seams", "classCGAL_1_1Seam__mesh.html#a38a1acc1778702eac340f131f106820c", null ],
      [ "add_seams", "classCGAL_1_1Seam__mesh.html#af4c70c55463aa2f0aac83a5e804370e9", null ],
      [ "add_seams", "classCGAL_1_1Seam__mesh.html#af60fb4b1e870002621a91dcc223eddc1", null ],
      [ "add_seams", "classCGAL_1_1Seam__mesh.html#a0d8dac794a4c1c334cbe657f7f218822", null ],
      [ "add_seams", "classCGAL_1_1Seam__mesh.html#aa58869c40c1e06a65bf8106582a901fd", null ],
      [ "degree", "classCGAL_1_1Seam__mesh.html#af2509141190b24f4806551ee2158b222", null ],
      [ "edges", "classCGAL_1_1Seam__mesh.html#a24a368539611a97e68d2f7d63ee8f08e", null ],
      [ "faces", "classCGAL_1_1Seam__mesh.html#ae11771b6b4172d94cf6290257c40381c", null ],
      [ "halfedges", "classCGAL_1_1Seam__mesh.html#a01fbd5b04ea371edef3c0b32c24adf3c", null ],
      [ "has_on_seam", "classCGAL_1_1Seam__mesh.html#ae8d7f4fa46f9a0687de1ee374461aad4", null ],
      [ "has_on_seam", "classCGAL_1_1Seam__mesh.html#a538645c6588bd1758f346a764bd0be2c", null ],
      [ "has_on_seam", "classCGAL_1_1Seam__mesh.html#ae242bfaba1e30dded1c93c0f0e6ed7ed", null ],
      [ "has_on_seam", "classCGAL_1_1Seam__mesh.html#a92b2bbe116b25c2669758ff389278bcb", null ],
      [ "mesh", "classCGAL_1_1Seam__mesh.html#a09c917082a1202edd7735a24b4e4b6f0", null ],
      [ "num_edges", "classCGAL_1_1Seam__mesh.html#a89bc8248be856601c38801ef3a4d71d0", null ],
      [ "num_faces", "classCGAL_1_1Seam__mesh.html#a1074cfb13d9f7bfd9df5b167857e0fc2", null ],
      [ "num_halfedges", "classCGAL_1_1Seam__mesh.html#a7a4f5c11d24981744a3552e4467e7e9a", null ],
      [ "num_vertices", "classCGAL_1_1Seam__mesh.html#ad17e2558d52311cc1c4ac48871afcea0", null ],
      [ "number_of_seam_edges", "classCGAL_1_1Seam__mesh.html#a981873898674185a6a0c27779042595e", null ],
      [ "vertices", "classCGAL_1_1Seam__mesh.html#a8d5f6b58d14c149b4e5bd9ffd9d08a6a", null ]
    ] ]
];

==> CGAL-6.1.1-doc_html.tar.xz: doc_html/BGL/group__PkgBGLAdaptors.js <==
var group__PkgBGLAdaptors =
[
    [ "CGAL::Graph_with_descriptor_with_graph< Graph_ >", "structCGAL_1_1Graph__with__descriptor__with__graph.html", null ],
    [ "CGAL::Graph_with_descriptor_with_graph_property_map< Graph, PM, Category >", "structCGAL_1_1Graph__with__descriptor__with__graph__property__map.html", null ],
    [ "CGAL::Face_filtered_graph< Graph, FIMap, VIMap, HIMap >", "structCGAL_1_1Face__filtered__graph.html", [
      [ "edge_descriptor", "structCGAL_1_1Face__filtered__graph.html#a39d585ed86d262a090636cdd22ca1217", null ],
      [ "face_descriptor", "structCGAL_1_1Face__filtered__graph.html#a205b4716fba186d69d6527df34110939", null ],
      [ "halfedge_descriptor", "structCGAL_1_1Face__filtered__graph.html#a7bbe5ebea8b1792c366fdbea6efbd1b0", null ],
      [ "size_type", "structCGAL_1_1Face__filtered__graph.html#a9f6a738f2a87c25f5c5606071a5fb1d0", null ],
      [ "vertex_descriptor", "structCGAL_1_1Face__filtered__graph.html#a137cc0e8f6c8f4d7a916280085ea9947", null ],
      [ "Face_filtered_graph", "structCGAL_1_1Face__filtered__graph.html#a17421e034850157f1c586d25dc436ab8", null ],
      [ "Face_filtered_graph", "structCGAL_1_1Face__filtered__graph.html#af4251ab8021448778e03aa344c15f5e3", null ],
      [ "Face_filtered_graph", "structCGAL_1_1Face__filtered__graph.html#a2205d4aab1986b515e93515e3f5f7575", null ],
      [ "Face_filtered_graph", "structCGAL_1_1Face__filtered__graph.html#ad4059cafe683c7b8e829957c6d22f231", null ],
      [ "graph", "structCGAL_1_1Face__filtered__graph.html#a0fabeb364eb0544ef90aa3c67be7c91f", null ],
      [ "graph", "structCGAL_1_1Face__filtered__graph.html#aeef8ac3160210bd61937981c8dbe1f52", null ],
      [ "invert_selection", "structCGAL_1_1Face__filtered__graph.html#aa428541ebbdd35f9a6e9a3ffd60178df", null ],
      [ "is_selection_valid", "structCGAL_1_1Face__filtered__graph.html#ae11ebf8f8253a1ccfe3783fd45cd7380", null ],
      [ "number_of_faces", "structCGAL_1_1Face__filtered__graph.html#ac82d8efddf90cb302e16f3dfa6ace359", null ],
      [ "number_of_halfedges", "structCGAL_1_1Face__filtered__graph.html#a8adaca786ab8cb5bbdbe59c2e645d792", null ],
      [ "number_of_vertices", "structCGAL_1_1Face__filtered__graph.html#a170f192e48bcdebdffeda0513f2410b1", null ],
      [ "set_selected_faces", "structCGAL_1_1Face__filtered__graph.html#a5dfc3c8ea8857d83579e92184c63ac80", null ],
      [ "set_selected_faces", "structCGAL_1_1Face__filtered__graph.html#a3a17351778505a646a75e150e5df47fb", null ],
      [ "set_selected_faces", "structCGAL_1_1Face__filtered__graph.html#a79f5692c21434777fa2c55bba476b509", null ]
    ] ],
    [ "CGAL::Dual< Primal_ >", "classCGAL_1_1Dual.html", [
      [ "Primal", "classCGAL_1_1Dual.html#a22a27f0319fa2626209231dfb37e4926", null ],
      [ "Dual", "classCGAL_1_1Dual.html#add5bcd5fa450de44a72f8fe633852528", null ],
      [ "primal", "classCGAL_1_1Dual.html#aad365ac3cbe67a3d487a63aa9b49cdec", null ],
      [ "dual", "classCGAL_1_1Dual.html#a85d851dbd90074098e101a10457f65a1", null ]
    ] ],
    [ "CGAL::Seam_mesh< TM, SEM, SVM >", "classCGAL_1_1Seam__mesh.html", [
      [ "edge_descriptor", "classCGAL_1_1Seam__mesh_1_1edge__descriptor.html", null ],
      [ "halfedge_descriptor", "classCGAL_1_1Seam__mesh_1_1halfedge__descriptor.html", [
        [ "halfedge_descriptor", "classCGAL_1_1Seam__mesh_1_1halfedge__descriptor.html#ab5fbff698dd4a46833e6eb0ee121d7a6", null ],
        [ "halfedge_descriptor", "classCGAL_1_1Seam__mesh_1_1halfedge__descriptor.html#ad5b9578608046cc6d7b3ce239f14fbbf", null ]
      ] ],
      [ "vertex_descriptor", "classCGAL_1_1Seam__mesh_1_1vertex__descriptor.html", [
        [ "vertex_descriptor", "classCGAL_1_1Seam__mesh_1_1vertex__descriptor.html#aa4bbff0637b5892384a6cf0baac15807", null ],
        [ "vertex_descriptor", "classCGAL_1_1Seam__mesh_1_1vertex__descriptor.html#ac8180d4af2fb242cd5c505fb9e60e686", null ]
      ] ],
      [ "degree_size_type", "classCGAL_1_1Seam__mesh.html#a742e105a8131a63557915badc1e4786a", null ],
      [ "edges_size_type", "classCGAL_1_1Seam__mesh.html#a6d7b18cd7aa8e79cef2cd817c1b592b5", null ],
      [ "face_descriptor", "classCGAL_1_1Seam__mesh.html#a1685be3946d66eb747da43f7cea27886", null ],
      [ "faces_size_type", "classCGAL_1_1Seam__mesh.html#ac81e17c02d209fa8f7177f8f2593fe67", null ],
      [ "halfedges_size_type", "classCGAL_1_1Seam__mesh.html#a30b80a167cf5c1a07d374831382c6183", null ],
      [ "TM_edge_descriptor", "classCGAL_1_1Seam__mesh.html#a262560916f975ef799db0fe30cb0b33d", null ],
      [ "TM_halfedge_descriptor", "classCGAL_1_1Seam__mesh.html#a251a9f5e67ef5e5d988ce59f7b9a171b", null ],
      [ "TM_halfedge_iterator", "classCGAL_1_1Seam__mesh.html#a18c491d5a3e51cc6b6f2c8f37085b586", null ],
      [ "TM_vertex_descriptor", "classCGAL_1_1Seam__mesh.html#af23c272b8e2353bacee1ebd31ef340f3", null ],
      [ "Triangle_mesh", "classCGAL_1_1Seam__mesh.html#aa926867198e66ecf3d324e41a3312f18", null ],
      [ "vertices_size_type", "classCGAL_1_1Seam__mesh.html#a6a8680b26948b92e06448026b266a20e", null ],
      [ "Seam_mesh", "classCGAL_1_1Seam__mesh.html#a6042bff5f91a335aee1bd2573b57a29f", null ],
      [ "add_seam", "classCGAL_1_1Seam__mesh.html#a27d5997959e6a348e7206e359a378d85", null ],
      [ "add_seams", "classCGAL_1_1Seam__mesh.html#aa58869c40c1e06a65bf8106582a901fd", null ],
      [ "add_seams", "classCGAL_1_1Seam__mesh.html#a0d8dac794a4c1c334cbe657f7f218822", null ],
      [ "add_seams", "classCGAL_1_1Seam__mesh.html#a38a1acc1778702eac340f131f106820c", null ],
      [ "add_seams", "classCGAL_1_1Seam__mesh.html#af60fb4b1e870002621a91dcc223eddc1", null ],
      [ "add_seams", "classCGAL_1_1Seam__mesh.html#af4c70c55463aa2f0aac83a5e804370e9", null ],
      [ "degree", "classCGAL_1_1Seam__mesh.html#af2509141190b24f4806551ee2158b222", null ],
      [ "edges", "classCGAL_1_1Seam__mesh.html#a2b624ad1845231bc4ef58d042db579e2", null ],
      [ "faces", "classCGAL_1_1Seam__mesh.html#aefefceac2f063664daf09b84d45a7230", null ],
      [ "halfedges", "classCGAL_1_1Seam__mesh.html#a68f0296c8af0b5ab017b9eb4266bb759", null ],
      [ "has_on_seam", "classCGAL_1_1Seam__mesh.html#a92b2bbe116b25c2669758ff389278bcb", null ],
      [ "has_on_seam", "classCGAL_1_1Seam__mesh.html#a538645c6588bd1758f346a764bd0be2c", null ],
      [ "has_on_seam", "classCGAL_1_1Seam__mesh.html#ae242bfaba1e30dded1c93c0f0e6ed7ed", null ],
      [ "has_on_seam", "classCGAL_1_1Seam__mesh.html#ae8d7f4fa46f9a0687de1ee374461aad4", null ],
      [ "mesh", "classCGAL_1_1Seam__mesh.html#aac588db68aaeec158f22233bdfe86b46", null ],
      [ "num_edges", "classCGAL_1_1Seam__mesh.html#a89bc8248be856601c38801ef3a4d71d0", null ],
      [ "num_faces", "classCGAL_1_1Seam__mesh.html#a1074cfb13d9f7bfd9df5b167857e0fc2", null ],
      [ "num_halfedges", "classCGAL_1_1Seam__mesh.html#a7a4f5c11d24981744a3552e4467e7e9a", null ],
      [ "num_vertices", "classCGAL_1_1Seam__mesh.html#ad17e2558d52311cc1c4ac48871afcea0", null ],
      [ "number_of_seam_edges", "classCGAL_1_1Seam__mesh.html#a981873898674185a6a0c27779042595e", null ],
      [ "vertices", "classCGAL_1_1Seam__mesh.html#afdf2160a0534be46233307d533160a26", null ]
    ] ]
];
